@@ -18,13 +18,13 @@
 
 #include "kmimetypechooser.h"
 
+#include "kmimetypeeditor.h"
 #include <qmimedatabase.h>
 
 #include <QApplication>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QLayout>
-#include <QProcess>
 #include <QPushButton>
 #include <QStandardPaths>
 #include <QTreeWidget>
@@ -223,17 +223,9 @@ void KMimeTypeChooserPrivate::_k_editMimeType()
     //q->connect( KSycoca::self(), SIGNAL(databaseChanged(QStringList)),
     //            q, SLOT(_k_slotSycocaDatabaseChanged(QStringList)) );
 #pragma message("KF5 TODO: use QFileSystemWatcher to be told when keditfiletype changed a mimetype")
+    // or a better idea: a QMimeDatabaseWatcher class in Qt itself
 
-    // TODO: Move this class to the kwidgets framework, no more kio dependency.
-
-    QStringList args;
-#ifndef Q_OS_WIN
-    args << QStringLiteral("--parent") << QString::number((ulong)q->topLevelWidget()->winId());
-#endif
-    args << QStringLiteral("--caption") << QGuiApplication::applicationDisplayName();
-    args << mt;
-
-    QProcess::startDetached(QString::fromLatin1(s_keditfiletypeExecutable), args);
+    KMimeTypeEditor::editMimeType(mt, q);
 }
 
 void KMimeTypeChooserPrivate::_k_slotCurrentChanged(QTreeWidgetItem *item)
